@@ -160,6 +160,7 @@ return {
       management = '$management_port',
       backend = '$backend_port',
       echo = '$echo_port',
+      metrics = '$ServerPort',
     },
     env = {
         THREESCALE_CONFIG_FILE = [[$configuration_file]],
@@ -191,7 +192,7 @@ _EOC_
         unlink $PidFile or warn "Couldn't remove $PidFile.\n";
     }
 
-    $ENV{APICAST_LOADED_ENVIRONMENTS} = $env_file;
+    $ENV{APICAST_LOADED_ENVIRONMENTS} = join('|',$ env_file, $block->environment_file);
 };
 
 BEGIN {
